@@ -79,18 +79,19 @@ class Dump(object):
         elif console:
             dataToStdout(text)
 
-        multiThreadMode = kb.multiThreadMode
-        if multiThreadMode:
-            self._lock.acquire()
+        if self._outputFP:
+            multiThreadMode = kb.multiThreadMode
+            if multiThreadMode:
+                self._lock.acquire()
 
-        try:
-            self._outputFP.write(text)
-        except IOError as ex:
-            errMsg = "error occurred while writing to log file ('%s')" % getSafeExString(ex)
-            raise SqlmapGenericException(errMsg)
+            try:
+                self._outputFP.write(text)
+            except IOError as ex:
+                errMsg = "error occurred while writing to log file ('%s')" % getSafeExString(ex)
+                raise SqlmapGenericException(errMsg)
 
-        if multiThreadMode:
-            self._lock.release()
+            if multiThreadMode:
+                self._lock.release()
 
         kb.dataOutputFlag = True
 
@@ -102,6 +103,10 @@ class Dump(object):
                 pass
 
     def setOutputFile(self):
+        if conf.noLogging:
+            self._outputFP = None
+            return
+
         self._outputFile = os.path.join(conf.outputPath, "log")
         try:
             self._outputFP = openFile(self._outputFile, "ab" if not conf.flushSession else "wb")
@@ -410,7 +415,15 @@ class Dump(object):
         try:
             dumpDbPath = os.path.join(conf.dumpPath, unsafeSQLIdentificatorNaming(db))
         except UnicodeError:
-            dumpDbPath = os.path.join(conf.dumpPath, normalizeUnicode(unsafeSQLIdentificatorNaming(db)))
+            try:
+                dumpDbPath = os.path.join(conf.dumpPath, normalizeUnicode(unsafeSQLIdentificatorNaming(db)))
+            except (UnicodeError, OSError):
+                tempDir = tempfile.mkdtemp(prefix="sqlmapdb")
+                warnMsg = "currently unable to use regular dump directory. "
+                warnMsg += "Using temporary directory '%s' instead" % tempDir
+                logger.warning(warnMsg)
+
+                dumpDbPath = tempDir
 
         if conf.dumpFormat == DUMP_FORMAT.SQLITE:
             replication = Replication(os.path.join(conf.dumpPath, "%s.sqlite3" % unsafeSQLIdentificatorNaming(db)))
@@ -432,7 +445,7 @@ class Dump(object):
                             warnMsg = "unable to create dump directory "
                             warnMsg += "'%s' (%s). " % (dumpDbPath, getSafeExString(ex))
                             warnMsg += "Using temporary directory '%s' instead" % tempDir
-                            logger.warn(warnMsg)
+                            logger.warning(warnMsg)
 
                             dumpDbPath = tempDir
 
@@ -611,7 +624,7 @@ class Dump(object):
                                 _ = re.sub(r"[^\w]", UNSAFE_DUMP_FILEPATH_REPLACEMENT, normalizeUnicode(unsafeSQLIdentificatorNaming(column)))
                                 filepath = os.path.join(dumpDbPath, "%s-%d.bin" % (_, randomInt(8)))
                                 warnMsg = "writing binary ('%s') content to file '%s' " % (mimetype, filepath)
-                                logger.warn(warnMsg)
+                                logger.warning(warnMsg)
 
                                 with openFile(filepath, "w+b", None) as f:
                                     _ = safechardecode(value, True)
@@ -659,7 +672,7 @@ class Dump(object):
             if not warnFile:
                 logger.info(msg)
             else:
-                logger.warn(msg)
+                logger.warning(msg)
 
     def dbColumns(self, dbColumnsDict, colConsider, dbs):
         if conf.api:
